package preload
import "github.com/google/certificate-transparency-go/preload"
Package preload holds code for adding batches of certificates to CT logs.
Index ¶
Types ¶
type AddedCert ¶
type AddedCert struct {
CertDER ct.ASN1Cert
SignedCertificateTimestamp ct.SignedCertificateTimestamp
AddedOk bool
ErrorMessage string
}
AddedCert holds information about a certificate that has been added to a log.
Source Files ¶
Directories ¶
| Path | Synopsis |
|---|---|
| preload/dumpscts | Dumpscts prints out SCTs written to a file by the preloader command in the ../preloader directory. |
| preload/preloader | Binary preloader submits certificates that may not already be present in CT Logs. |
- Version
- v1.3.2 (latest)
- Published
- Jun 13, 2025
- Platform
- linux/amd64
- Imports
- 1 packages
- Last checked
- 9 months ago –
Tools for package owners.